@@ -7,7 +7,7 @@ use Log::Any '$log';
 
 use Scalar::Util qw(blessed);
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -75,7 +75,7 @@ sub _generate_cleanser_code {
     my $n = 0;
     my $add_if = sub {
         my ($cond0, $act0) = @_;
-        for ([\@ifs_ary, '$a->[$i]'], [\@ifs_hash, '$h->{$k}'], [\@ifs_main, '$_']) {
+        for ([\@ifs_ary, '$e'], [\@ifs_hash, '$h->{$k}'], [\@ifs_main, '$_']) {
             my $act  = $act0 ; $act  =~ s/\Q{{var}}\E/$_->[1]/g;
             my $cond = $cond0; $cond =~ s/\Q{{var}}\E/$_->[1]/g;
             push @{ $_->[0] }, "    ".($n ? "els":"")."if ($cond) { $act }\n";
@@ -118,7 +118,7 @@ sub _generate_cleanser_code {
     push @code, 'state %refs;'."\n" if $circ;
     push @code, 'state $process_array;'."\n";
     push @code, 'state $process_hash;'."\n";
-    push @code, 'if (!$process_array) { $process_array = sub { my $a = shift; for my $i (0..$#$a) { my $ref=ref($a->[$i]);'."\n".join("", @ifs_ary).'} } }'."\n";
+    push @code, 'if (!$process_array) { $process_array = sub { my $a = shift; for my $e (@$a) { my $ref=ref($e);'."\n".join("", @ifs_ary).'} } }'."\n";
     push @code, 'if (!$process_hash) { $process_hash = sub { my $h = shift; for my $k (keys %$h) { my $ref=ref($h->{$k});'."\n".join("", @ifs_hash).'} } }'."\n";
     push @code, '%refs = ();'."\n" if $circ;
     push @code, 'for ($data) { my $ref=ref($_);'."\n".join("", @ifs_main).'}'."\n";
@@ -163,7 +163,7 @@ Data::Clean::Base - Base class for Data::Clean::*
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =for Pod::Coverage ^(command_.+)$
 
